@@ -13,7 +13,7 @@
 #' @seealso [predict_workers()], [build_times()], [make()]
 #' @examples
 #' \dontrun{
-#' test_with_dir("Quarantine side effects.", {
+#' isolate_example("Quarantine side effects.", {
 #' if (suppressWarnings(require("knitr"))) {
 #' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Run the project, build the targets.
@@ -80,7 +80,7 @@ predict_runtime <- function(
 #' @seealso [predict_runtime()], [build_times()], [make()]
 #' @examples
 #' \dontrun{
-#' test_with_dir("Quarantine side effects.", {
+#' isolate_example("Quarantine side effects.", {
 #' if (suppressWarnings(require("knitr"))) {
 #' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Run the project, build the targets.
@@ -175,14 +175,6 @@ worker_prediction_info <- function(
 ) {
   assert_config_not_plan(config)
   deprecate_targets_only(targets_only) # 2019-01-03 # nolint
-  if (!is.null(targets)) {
-    config$schedule <- nbhd_graph(
-      config$schedule,
-      vertices = targets,
-      mode = "in",
-      order = igraph::gorder(config$schedule)
-    )
-  }
   assumptions <- timing_assumptions(
     config = config,
     targets = targets,
@@ -192,6 +184,15 @@ worker_prediction_info <- function(
     default_time = default_time,
     warn = warn
   )
+  config$graph <- subset_graph(config$graph, all_targets(config))
+  if (!is.null(targets)) {
+    config$graph <- nbhd_graph(
+      config$graph,
+      vertices = targets,
+      mode = "in",
+      order = igraph::gorder(config$graph)
+    )
+  }
   queue <- new_priority_queue(config, jobs = 1)
   running <- data.frame(
     target = character(0),
@@ -246,7 +247,7 @@ timing_assumptions <- function(
     outdated <- outdated(config)
   }
   times <- build_times(cache = config$cache)
-  vertices <- igraph::V(config$schedule)$name
+  vertices <- all_targets(config)
   times <- times[times$target %in% vertices, ]
   untimed <- setdiff(vertices, times$target)
   untimed <- setdiff(untimed, names(known_times))
@@ -267,7 +268,7 @@ timing_assumptions <- function(
   assumptions[times$target] <- times$elapsed
   assumptions[names(known_times)] <- known_times
   if (!from_scratch) {
-    skip <- setdiff(config$plan$target, outdated)
+    skip <- setdiff(all_targets(config), outdated)
     assumptions[skip] <- 0
   }
   assumptions
