@@ -98,6 +98,13 @@ default_system2_args <- drake_defunct
 #' @param ... Arguments
 deprecate_wildcard <- drake_defunct
 
+#' @title Defunct function
+#' @description 2019-05-16
+#' @export
+#' @keywords internal
+#' @param ... Arguments
+deps <- drake_defunct
+
 #' @title Defunct function
 #' @description 2019-02-15
 #' @export
@@ -161,6 +168,20 @@ is_function_call <- drake_defunct
 #' @param ... Arguments
 load_basic_example <- drake_defunct
 
+#' @title Defunct function
+#' @description 2019-05-16
+#' @export
+#' @keywords internal
+#' @param ... Arguments
+max_useful_jobs <- drake_defunct
+
+#' @title Defunct function
+#' @description 2019-05-16
+#' @export
+#' @keywords internal
+#' @param ... Arguments
+migrate_drake_project <- drake_defunct
+
 #' @title Defunct function
 #' @description 2019-02-15
 #' @export
